package cn.com.countrygarden.bi.main.service.project.impl.vo;

public class IndicatorLight {
//	private Integer oYellow;
//	private Integer oRed;
	private Integer aYellow;
	private Integer aRed;
	private Integer aBlack;
	private Integer bYellow;
	private Integer bRed;
	private Integer bBlack;
	private Integer cYellow;
	private Integer cRed;
	private Integer cBlack;
	private Integer dYellow;
	private Integer dRed;
	private Integer dBlack;
	
public Integer getaBlack() {
		return aBlack;
	}
	public void setaBlack(Integer aBlack) {
		this.aBlack = aBlack;
	}
	public Integer getbBlack() {
		return bBlack;
	}
	public void setbBlack(Integer bBlack) {
		this.bBlack = bBlack;
	}
	public Integer getcBlack() {
		return cBlack;
	}
	public void setcBlack(Integer cBlack) {
		this.cBlack = cBlack;
	}
	public Integer getdBlack() {
		return dBlack;
	}
	public void setdBlack(Integer dBlack) {
		this.dBlack = dBlack;
	}
	//	public Integer getoYellow() {
//		return oYellow;
//	}
//	public void setoYellow(Integer oYellow) {
//		this.oYellow = oYellow;
//	}
//	public Integer getoRed() {
//		return oRed;
//	}
//	public void setoRed(Integer oRed) {
//		this.oRed = oRed;
//	}
	public Integer getaYellow() {
		return aYellow;
	}
	public void setaYellow(Integer aYellow) {
		this.aYellow = aYellow;
	}
	public Integer getaRed() {
		return aRed;
	}
	public void setaRed(Integer aRed) {
		this.aRed = aRed;
	}
	public Integer getbYellow() {
		return bYellow;
	}
	public void setbYellow(Integer bYellow) {
		this.bYellow = bYellow;
	}
	public Integer getbRed() {
		return bRed;
	}
	public void setbRed(Integer bRed) {
		this.bRed = bRed;
	}
	public Integer getcYellow() {
		return cYellow;
	}
	public void setcYellow(Integer cYellow) {
		this.cYellow = cYellow;
	}
	public Integer getcRed() {
		return cRed;
	}
	public void setcRed(Integer cRed) {
		this.cRed = cRed;
	}
	public Integer getdYellow() {
		return dYellow;
	}
	public void setdYellow(Integer dYellow) {
		this.dYellow = dYellow;
	}
	public Integer getdRed() {
		return dRed;
	}
	public void setdRed(Integer dRed) {
		this.dRed = dRed;
	}

}
